yakumo.nova.v2.cloudpipe.Manager

Package yakumo :: Package nova :: Package v2 :: Module cloudpipe :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for cloudpipes in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for cloudpipes in Compute API v2

Instance Methods | [hide private]
yakumo.nova.v2.cloudpipe.Resource |
create(self, project=`'``__UNDEF__``'`) Create a cloudpipe | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``server``'``,` `'``instance_id``'``,` <yakumo.mapper.Reso`...``
| _id_attr = ``'``server``'``
| _json_resource_key = ``'``cloudpipe``'``
| _json_resources_key = ``'``cloudpipes``'``
| _url_resource_path = ``'``/os-cloudpipe``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, project=`'``__UNDEF__``'`) | source code
Create a cloudpipe Parameters: `project` (yakumo.project.Resource) - Project Returns: yakumo.nova.v2.cloudpipe.Resource Created cloudpipe Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('server',
        'instance_id',
        <yakumo.mapper.Resource object at 0x7f132fed5110>),
       ('project',
        'project_id',
        <yakumo.mapper.Resource object at 0x7f132fed5150>),
       ('internal_ip',
        'internal_ip',
      ...